@@ -22,7 +22,8 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <string.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 
 #include "callbacks.h"
@@ -51,7 +52,7 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *window;
-	GtkWidget *menu_about;
+	GtkWidget *menu_quit, *menu_about, *menu_copy, *menu_clear_history;
 	GladeXML *xml;
 	GtkWidget *notebook;
 	const gchar *dialog = DATADIR "gnome-nettool.glade";
@@ -73,33 +74,41 @@ main (int argc, char *argv[])
 	static gchar *lookup_input = NULL;
 	static gchar *finger_input = NULL;
 	static gchar *whois_input = NULL;
-	static const struct poptOption options[] = {
-		{ "info", 'i', POPT_ARG_STRING, &info_input, 0,
-		  N_("Load information for a network device"),
-		  N_("DEVICE") },
-		{ "ping", 'p', POPT_ARG_STRING, &ping_input, 0,
-		  N_("Send a ping to a network address"),
-		  N_("HOST") },
-		{ "netstat", 'n', POPT_ARG_STRING, &netstat_input, 0,
-		  N_("Get netstat information.  Valid options are: route, active, multicast."),
-		  N_("COMMAND") },
-		{ "traceroute", 't', POPT_ARG_STRING, &traceroute_input, 0,
-		  N_("Trace a route to a network address"),
-		  N_("HOST") },
-		{ "port-scan", 's', POPT_ARG_STRING, &scan_input, 0,
-		  N_("Port scan a network address"),
-		  N_("HOST") },
-		{ "lookup", 'l', POPT_ARG_STRING, &lookup_input, 0,
-		  N_("Look up a network address"),
-		  N_("HOST") },
-		{ "finger", 'f', POPT_ARG_STRING, &finger_input, 0,
-		  N_("Finger command to run"),
-		  N_("USER") },
-		{ "whois", 'w', POPT_ARG_STRING, &whois_input, 0,
-		  N_("Perform a whois lookup for a network domain"),
-		  N_("DOMAIN") },
-		{ NULL, '\0', 0, NULL, 0 }
-	};
+	GOptionEntry options[] = {
+		{ "info", 'i', 0, G_OPTION_ARG_STRING, &info_input,
+ 		  N_("Load information for a network device"),
+ 		  N_("DEVICE") },
+
+		{ "ping", 'p', 0, G_OPTION_ARG_STRING, &ping_input,
+ 		  N_("Send a ping to a network address"),
+ 		  N_("HOST") },
+
+		{ "netstat", 'n', 0, G_OPTION_ARG_STRING, &netstat_input,
+ 		  N_("Get netstat information.  Valid options are: route, active, multicast."),
+ 		  N_("COMMAND") },
+
+		{ "traceroute", 't', 0, G_OPTION_ARG_STRING, &traceroute_input,
+ 		  N_("Trace a route to a network address"),
+ 		  N_("HOST") },
+
+		{ "port-scan", 's', 0, G_OPTION_ARG_STRING, &scan_input,
+ 		  N_("Port scan a network address"),
+ 		  N_("HOST") },
+
+		{ "lookup", 'l', 0, G_OPTION_ARG_STRING, &lookup_input,
+ 		  N_("Look up a network address"),
+ 		  N_("HOST") },
+
+		{ "finger", 'f', 0, G_OPTION_ARG_STRING, &finger_input,
+ 		  N_("Finger command to run"),
+ 		  N_("USER") },
+
+		{ "whois", 'w', 0, G_OPTION_ARG_STRING, &whois_input,
+ 		  N_("Perform a whois lookup for a network domain"),
+ 		  N_("DOMAIN") },
+
+		{ NULL, '\0', 0, 0, NULL, NULL, NULL }
+ 	};
 
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, GNOME_NETTOOL_LOCALEDIR);
@@ -107,17 +116,11 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_HUMAN_READABLE_NAME,
-			    _("Network Information"),
-			    GNOME_PARAM_POPT_TABLE, options,
-			    GNOME_PARAM_APP_DATADIR, DATADIR,
-			    GNOME_PARAM_NONE);
+	gtk_init_with_args (&argc, &argv,NULL,options,NULL,NULL);
 
 	if (!g_file_test (dialog, G_FILE_TEST_EXISTS)) {
 		g_critical (_("The file %s doesn't exist, "
-			      "please check if gnome-netinfo is correcly installed"),
+			      "please check if gnome-nettool is correctly installed"),
 			    dialog);
 		return -1;
 	}
@@ -134,12 +137,6 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (window), "delete-event",
 			  G_CALLBACK (gn_quit_app), NULL);
 	
-	menu_about = glade_xml_get_widget (xml, "m_about");
-
-	g_signal_connect (G_OBJECT (menu_about), "activate",
-			  G_CALLBACK (on_about_activate),
-			  (gpointer) window);
-
 	pinger = load_ping_widgets_from_xml (xml);
 	tracer = load_traceroute_widgets_from_xml (xml);
 	netstat = load_netstat_widgets_from_xml (xml);
@@ -213,6 +210,33 @@ main (int argc, char *argv[])
 	g_object_set_data (G_OBJECT (notebook), "finger", finger);
 	g_object_set_data (G_OBJECT (notebook), "whois", whois);
 	
+	menu_quit = glade_xml_get_widget (xml, "m_quit");
+	
+	g_signal_connect (G_OBJECT (menu_quit), "activate",
+			  G_CALLBACK (gn_quit_app),
+			  NULL);
+	
+	menu_about = glade_xml_get_widget (xml, "m_about");
+
+	g_signal_connect (G_OBJECT (menu_about), "activate",
+			  G_CALLBACK (on_about_activate),
+			  (gpointer) window);
+			  	
+	menu_copy = glade_xml_get_widget (xml, "m_copy");
+
+	g_signal_connect (G_OBJECT (menu_copy), "activate",
+			  G_CALLBACK (on_copy_activate),
+			  (gpointer) notebook);
+	
+	menu_clear_history = glade_xml_get_widget (xml, "m_clear_history");
+
+	g_signal_connect (G_OBJECT (menu_clear_history), "activate",
+			  G_CALLBACK (on_clear_history_activate),
+			  (gpointer) notebook);
+			  
+	
+	
+	
 	glade_xml_signal_autoconnect (xml);
 	g_object_unref (G_OBJECT (xml));
 
@@ -257,9 +281,11 @@ load_ping_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *pinger;
 	GtkWidget *vbox_ping;
+	GtkWidget *label;
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -288,7 +314,13 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	pinger->packets_received = glade_xml_get_widget (xml, "ping_packets_received");
 	pinger->packets_loss = glade_xml_get_widget (xml, "ping_packets_loss");
 
+	pinger->status_bar = glade_xml_get_widget (xml, "statusbar");
+	pinger->stbar_text = NULL;
+
 	vbox_ping = glade_xml_get_widget (xml, "vbox_ping");
+
+	label = glade_xml_get_widget (xml, "ping_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pinger->host);
 	
 	pinger->button_callback = G_CALLBACK (on_ping_activate);
 	pinger->process_line = NETINFO_FOREACH_FUNC (ping_foreach_with_tree);
@@ -301,6 +333,11 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (pinger->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (pinger->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the network address to ping.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 	
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -316,6 +353,9 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	g_signal_connect (G_OBJECT (entry_host), "activate",
 			  G_CALLBACK (on_ping_activate),
 			  pinger);
+	g_signal_connect (G_OBJECT (pinger->limited), "toggled",
+			  G_CALLBACK (on_ping_toggled),
+			  pinger);
 	g_signal_connect (G_OBJECT (pinger->button), "clicked",
 			  pinger->button_callback,
 			  pinger);
@@ -329,9 +369,11 @@ load_traceroute_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *tracer;
 	GtkWidget *vbox_traceroute;
+	GtkWidget *label;
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -353,9 +395,15 @@ load_traceroute_widgets_from_xml (GladeXML * xml)
 	tracer->routing = NULL;
 	tracer->protocol = NULL;
 	tracer->multicast = NULL;
+
+	tracer->status_bar = glade_xml_get_widget (xml, "statusbar");
+	tracer->stbar_text = NULL;
 	
 	vbox_traceroute = glade_xml_get_widget (xml, "vbox_traceroute");
 
+	label = glade_xml_get_widget (xml, "traceroute_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), tracer->host);
+
 	tracer->button_callback = G_CALLBACK (on_traceroute_activate);
 	tracer->process_line = NETINFO_FOREACH_FUNC (traceroute_foreach_with_tree);
 	tracer->copy_output = NETINFO_COPY_FUNC (traceroute_copy_to_clipboard);
@@ -367,6 +415,11 @@ load_traceroute_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (tracer->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (tracer->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the network address to trace a route to.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -415,6 +468,9 @@ load_netstat_widgets_from_xml (GladeXML * xml)
 	netstat->sensitive = NULL;
 	netstat->label_run = _("Netstat");
 	netstat->label_stop = NULL;
+
+	netstat->status_bar = glade_xml_get_widget (xml, "statusbar");
+	netstat->stbar_text = NULL;
 	
 	vbox_netstat = glade_xml_get_widget (xml, "vbox_netstat");
 	
@@ -497,6 +553,7 @@ load_info_widgets_from_xml (GladeXML * xml)
 	info = g_malloc (sizeof (Netinfo));
 
 	info->main_window = glade_xml_get_widget (xml, "main_window");
+	info->running = FALSE;
 	info->combo = glade_xml_get_widget (xml, "info_combo");
 	info->ipv6_frame = glade_xml_get_widget (xml, "info_ipv6_frame");
 	info->ipv4_frame = glade_xml_get_widget (xml, "info_ipv4_frame");
@@ -520,6 +577,9 @@ load_info_widgets_from_xml (GladeXML * xml)
 	info->list_ip_addr = glade_xml_get_widget (xml, "info_list_ip_addr");
 	info->configure_button = glade_xml_get_widget (xml, "info_configure_button");
 
+	info->status_bar = glade_xml_get_widget (xml, "statusbar");
+	info->stbar_text = NULL;
+
 	info->network_tool_path = util_find_program_in_path (GST_NETWORK_TOOL, NULL);
 
 	model = GTK_TREE_MODEL (gtk_list_store_new (5, G_TYPE_STRING, G_TYPE_STRING,
@@ -537,9 +597,9 @@ load_info_widgets_from_xml (GladeXML * xml)
 	gtk_size_group_add_widget (group, label2);
 	g_object_unref (group);
 
-/*
-#ifdef IFCONFIG_PROGRAM
-*/
+	label1 = glade_xml_get_widget (xml, "info_combo_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label1), info->combo);
+
 	model = GTK_TREE_MODEL (gtk_list_store_new (3, GDK_TYPE_PIXBUF,
 						    G_TYPE_STRING,
 						    G_TYPE_POINTER));
@@ -556,11 +616,6 @@ load_info_widgets_from_xml (GladeXML * xml)
 			  info);
 	
 	info_load_iface (info);
-/*
-#else
-	gtk_widget_set_sensitive (vbox_info, FALSE);
-#endif
-*/
 	info->copy_output = NETINFO_COPY_FUNC (info_copy_to_clipboard);
 
 	return info;
@@ -571,8 +626,10 @@ load_scan_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *scan;
 	GtkEntry  *entry_host;
+	GtkWidget *label;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -594,7 +651,13 @@ load_scan_widgets_from_xml (GladeXML * xml)
 	scan->sensitive = NULL;
 	scan->label_run = _("Scan");
 	scan->label_stop = NULL;
+
+	scan->status_bar = glade_xml_get_widget (xml, "statusbar");
+	scan->stbar_text = NULL;
 	
+	label = glade_xml_get_widget (xml, "scan_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), scan->host);
+
 	scan->button_callback = G_CALLBACK (on_scan_activate);
 	scan->copy_output = NETINFO_COPY_FUNC (scan_copy_to_clipboard);
 	scan->process_line = NETINFO_FOREACH_FUNC (scan_foreach);
@@ -606,6 +669,11 @@ load_scan_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (scan->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (scan->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the network address to scan for open ports.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -678,9 +746,11 @@ load_lookup_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *lookup;
 	GtkWidget *vbox_lookup;
+	GtkWidget *label;
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -703,9 +773,17 @@ load_lookup_widgets_from_xml (GladeXML * xml)
 	lookup->routing = NULL;
 	lookup->protocol = NULL;
 	lookup->multicast = NULL;
+
+	lookup->status_bar = glade_xml_get_widget (xml, "statusbar");
+	lookup->stbar_text = NULL;
 	
 	vbox_lookup = glade_xml_get_widget (xml, "vbox_lookup");
 
+	label = glade_xml_get_widget (xml, "lookup_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), lookup->host);
+	label = glade_xml_get_widget (xml, "lookup_type_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), lookup->type);
+
 	lookup->button_callback = G_CALLBACK (on_lookup_activate);
 	lookup->process_line = NETINFO_FOREACH_FUNC (lookup_foreach_with_tree);
 	lookup->copy_output = NETINFO_COPY_FUNC (lookup_copy_to_clipboard);
@@ -719,6 +797,11 @@ load_lookup_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (lookup->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (lookup->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the network address to lookup.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -747,10 +830,12 @@ load_finger_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *finger;
 	GtkWidget *vbox_finger;
+	GtkWidget *label;
 	PangoFontDescription *font_desc;
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -774,9 +859,17 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	finger->routing = NULL;
 	finger->protocol = NULL;
 	finger->multicast = NULL;
+
+	finger->status_bar = glade_xml_get_widget (xml, "statusbar");
+	finger->stbar_text = NULL;
 	
 	vbox_finger = glade_xml_get_widget (xml, "vbox_finger");
 
+	label = glade_xml_get_widget (xml, "finger_user_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), finger->user);
+	label = glade_xml_get_widget (xml, "finger_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), finger->host);
+
 	font_desc = pango_font_description_new ();
 	pango_font_description_set_family (font_desc, "monospace");
 	gtk_widget_modify_font (finger->output, font_desc);
@@ -793,6 +886,10 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->user), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->user)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the user to finger."),
+			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -816,6 +913,11 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter the network address to finger that user.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -845,9 +947,11 @@ load_whois_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo *whois;
 	GtkWidget *vbox_whois;
+	GtkWidget *label;
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
+	GtkTooltips *tips;
 	PangoFontDescription *font_desc;
 	
 
@@ -872,8 +976,14 @@ load_whois_widgets_from_xml (GladeXML * xml)
 	whois->protocol = NULL;
 	whois->multicast = NULL;
 
+	whois->status_bar = glade_xml_get_widget (xml, "statusbar");
+	whois->stbar_text = NULL;
+
 	vbox_whois = glade_xml_get_widget (xml, "vbox_whois");
 
+	label = glade_xml_get_widget (xml, "whois_host_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), whois->host);
+
 	font_desc = pango_font_description_new ();
 	pango_font_description_set_family (font_desc, "monospace");
 	gtk_widget_modify_font (whois->output, font_desc);
@@ -890,6 +1000,11 @@ load_whois_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (whois->host), 0);*/
 	
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (whois->host)));
+	tips = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
+			      _("Enter a domain address to lookup its whois information.\n"
+				"For example: www.domain.com or 192.168.2.1"),
+			      NULL);
 	
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
